:mod:`kwant.builder` -- High-level construction of systems
==========================================================

.. module:: kwant.builder

Types
-----
.. autosummary::
   :toctree: generated/

   Builder
   Site
   HoppingKind
   SimpleSiteFamily
   BuilderLead
   SelfEnergyLead
   ModesLead
   FiniteSystem
   InfiniteSystem

Abstract base classes
---------------------
.. autosummary::
   :toctree: generated/

   SiteFamily
   Symmetry
   Lead
